@@ -84,6 +84,7 @@ for( i in seq( along = formulas ) ) {
       inst = inst, methodResidCov = "noDfCor", restrict.matrix = restrm,
       method3sls = formulas[ i ], useMatrix = useMatrix )
    print( summary( fit3sls[[ i ]]$e2e, useDfSys = TRUE ) )
+   print( nobs( fit3sls[[i]]$e2e ))
 
    print( "*************** W3SLS with restriction *****************" )
    fit3sls[[ i ]]$e2w <- systemfit( system, "3SLS", data = Kmenta,
@@ -826,23 +827,23 @@ print( logLik( fit3slsd[[ 5 ]]$e2we ) )
 
 ## ************** F tests ****************
 # testing first restriction
-print( linear.hypothesis( fit3sls[[ 1 ]]$e1, restrm ) )
-linear.hypothesis( fit3sls[[ 1 ]]$e1, restrict )
+print( linearHypothesis( fit3sls[[ 1 ]]$e1, restrm ) )
+linearHypothesis( fit3sls[[ 1 ]]$e1, restrict )
 
-print( linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrm ) )
-linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrict )
+print( linearHypothesis( fit3sls[[ 2 ]]$e1e, restrm ) )
+linearHypothesis( fit3sls[[ 2 ]]$e1e, restrict )
 
-print( linear.hypothesis( fit3sls[[ 3 ]]$e1c, restrm ) )
-linear.hypothesis( fit3sls[[ 3 ]]$e1c, restrict )
+print( linearHypothesis( fit3sls[[ 3 ]]$e1c, restrm ) )
+linearHypothesis( fit3sls[[ 3 ]]$e1c, restrict )
 
-print( linear.hypothesis( fit3slsi[[ 4 ]]$e1, restrm ) )
-linear.hypothesis( fit3slsi[[ 4 ]]$e1, restrict )
+print( linearHypothesis( fit3slsi[[ 4 ]]$e1, restrm ) )
+linearHypothesis( fit3slsi[[ 4 ]]$e1, restrict )
 
-print( linear.hypothesis( fit3slsd[[ 5 ]]$e1e, restrm ) )
-linear.hypothesis( fit3slsd[[ 5 ]]$e1e, restrict )
+print( linearHypothesis( fit3slsd[[ 5 ]]$e1e, restrm ) )
+linearHypothesis( fit3slsd[[ 5 ]]$e1e, restrict )
 
-print( linear.hypothesis( fit3slsd[[ 2 ]]$e1w, restrm ) )
-linear.hypothesis( fit3slsd[[ 2 ]]$e1w, restrict )
+print( linearHypothesis( fit3slsd[[ 2 ]]$e1w, restrm ) )
+linearHypothesis( fit3slsd[[ 2 ]]$e1w, restrict )
 
 # testing second restriction
 restrOnly2m <- matrix(0,1,7)
@@ -851,128 +852,128 @@ restrOnly2m[1,2] <- -1
 restrOnly2m[1,5] <-  1
 restrictOnly2 <- "- demand_price + supply_price = 0.5"
 # first restriction not imposed
-print( linear.hypothesis( fit3sls[[ 5 ]]$e1c, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3sls[[ 5 ]]$e1c, restrictOnly2 )
+print( linearHypothesis( fit3sls[[ 5 ]]$e1c, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3sls[[ 5 ]]$e1c, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsi[[ 1 ]]$e1e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsi[[ 1 ]]$e1e, restrictOnly2 )
+print( linearHypothesis( fit3slsi[[ 1 ]]$e1e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsi[[ 1 ]]$e1e, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsi[[ 3 ]]$e1we, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsi[[ 3 ]]$e1we, restrictOnly2 )
+print( linearHypothesis( fit3slsi[[ 3 ]]$e1we, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsi[[ 3 ]]$e1we, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsd[[ 2 ]]$e1, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsd[[ 2 ]]$e1, restrictOnly2 )
+print( linearHypothesis( fit3slsd[[ 2 ]]$e1, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsd[[ 2 ]]$e1, restrictOnly2 )
 
 # first restriction imposed
-print( linear.hypothesis( fit3sls[[ 4 ]]$e2, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3sls[[ 4 ]]$e2, restrictOnly2 )
+print( linearHypothesis( fit3sls[[ 4 ]]$e2, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3sls[[ 4 ]]$e2, restrictOnly2 )
 
-print( linear.hypothesis( fit3sls[[ 4 ]]$e3, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3sls[[ 4 ]]$e3, restrictOnly2 )
+print( linearHypothesis( fit3sls[[ 4 ]]$e3, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3sls[[ 4 ]]$e3, restrictOnly2 )
 
-print( linear.hypothesis( fit3sls[[ 1 ]]$e2w, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3sls[[ 1 ]]$e2w, restrictOnly2 )
+print( linearHypothesis( fit3sls[[ 1 ]]$e2w, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3sls[[ 1 ]]$e2w, restrictOnly2 )
 
-print( linear.hypothesis( fit3sls[[ 1 ]]$e3we, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3sls[[ 1 ]]$e3we, restrictOnly2 )
+print( linearHypothesis( fit3sls[[ 1 ]]$e3we, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3sls[[ 1 ]]$e3we, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsi[[ 5 ]]$e2e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsi[[ 5 ]]$e2e, restrictOnly2 )
+print( linearHypothesis( fit3slsi[[ 5 ]]$e2e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsi[[ 5 ]]$e2e, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsi[[ 5 ]]$e3e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsi[[ 5 ]]$e3e, restrictOnly2 )
+print( linearHypothesis( fit3slsi[[ 5 ]]$e3e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsi[[ 5 ]]$e3e, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsd[[ 1 ]]$e2, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsd[[ 1 ]]$e2, restrictOnly2 )
+print( linearHypothesis( fit3slsd[[ 1 ]]$e2, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsd[[ 1 ]]$e2, restrictOnly2 )
 
-print( linear.hypothesis( fit3slsd[[ 1 ]]$e3, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fit3slsd[[ 1 ]]$e3, restrictOnly2 )
+print( linearHypothesis( fit3slsd[[ 1 ]]$e3, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fit3slsd[[ 1 ]]$e3, restrictOnly2 )
 
 # testing both of the restrictions
-print( linear.hypothesis( fit3sls[[ 2 ]]$e1e, restr2m, restr2q ) )
-linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrict2 )
+print( linearHypothesis( fit3sls[[ 2 ]]$e1e, restr2m, restr2q ) )
+linearHypothesis( fit3sls[[ 2 ]]$e1e, restrict2 )
 
-print( linear.hypothesis( fit3slsi[[ 3 ]]$e1, restr2m, restr2q ) )
-linear.hypothesis( fit3slsi[[ 3 ]]$e1, restrict2 )
+print( linearHypothesis( fit3slsi[[ 3 ]]$e1, restr2m, restr2q ) )
+linearHypothesis( fit3slsi[[ 3 ]]$e1, restrict2 )
 
-print( linear.hypothesis( fit3slsd[[ 4 ]]$e1e, restr2m, restr2q ) )
-linear.hypothesis( fit3slsd[[ 4 ]]$e1e, restrict2 )
+print( linearHypothesis( fit3slsd[[ 4 ]]$e1e, restr2m, restr2q ) )
+linearHypothesis( fit3slsd[[ 4 ]]$e1e, restrict2 )
 
-print( linear.hypothesis( fit3slsd[[ 5 ]]$e1w, restr2m, restr2q ) )
-linear.hypothesis( fit3slsd[[ 5 ]]$e1w, restrict2 )
+print( linearHypothesis( fit3slsd[[ 5 ]]$e1w, restr2m, restr2q ) )
+linearHypothesis( fit3slsd[[ 5 ]]$e1w, restrict2 )
 
 
 ## ************** Wald tests ****************
 # testing first restriction
-print( linear.hypothesis( fit3sls[[ 1 ]]$e1, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 1 ]]$e1, restrict, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 1 ]]$e1, restrm, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 1 ]]$e1, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrict, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 2 ]]$e1e, restrm, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 2 ]]$e1e, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fit3sls[[ 3 ]]$e1c, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 3 ]]$e1c, restrict, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 3 ]]$e1c, restrm, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 3 ]]$e1c, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 4 ]]$e1, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 4 ]]$e1, restrict, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 4 ]]$e1, restrm, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 4 ]]$e1, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 2 ]]$e1we, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 2 ]]$e1we, restrict, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 2 ]]$e1we, restrm, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 2 ]]$e1we, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 5 ]]$e1e, restrm, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 5 ]]$e1e, restrict, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 5 ]]$e1e, restrm, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 5 ]]$e1e, restrict, test = "Chisq" )
 
 # testing second restriction
 # first restriction not imposed
-print( linear.hypothesis( fit3sls[[ 5 ]]$e1c, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 5 ]]$e1c, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 5 ]]$e1c, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 5 ]]$e1c, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3sls[[ 3 ]]$e1wc, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 3 ]]$e1wc, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 3 ]]$e1wc, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 3 ]]$e1wc, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 1 ]]$e1e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 1 ]]$e1e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 1 ]]$e1e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 1 ]]$e1e, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 2 ]]$e1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 2 ]]$e1, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 2 ]]$e1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 2 ]]$e1, restrictOnly2, test = "Chisq" )
 
 # first restriction imposed
-print( linear.hypothesis( fit3sls[[ 4 ]]$e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 4 ]]$e2, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 4 ]]$e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 4 ]]$e2, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3sls[[ 4 ]]$e3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 4 ]]$e3, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 4 ]]$e3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 4 ]]$e3, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 5 ]]$e2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 5 ]]$e2e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 5 ]]$e2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 5 ]]$e2e, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 5 ]]$e3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 5 ]]$e3e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 5 ]]$e3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 5 ]]$e3e, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 1 ]]$e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 1 ]]$e2, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 1 ]]$e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 1 ]]$e2, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 1 ]]$e3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 1 ]]$e3, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 1 ]]$e3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 1 ]]$e3, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 2 ]]$e2we, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 2 ]]$e2we, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 2 ]]$e2we, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 2 ]]$e2we, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 3 ]]$e3w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 3 ]]$e3w, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 3 ]]$e3w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 3 ]]$e3w, restrictOnly2, test = "Chisq" )
 
 # testing both of the restrictions
-print( linear.hypothesis( fit3sls[[ 2 ]]$e1e, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 2 ]]$e1e, restrict2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 2 ]]$e1e, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 2 ]]$e1e, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fit3sls[[ 5 ]]$e1wc, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fit3sls[[ 5 ]]$e1wc, restrict2, test = "Chisq" )
+print( linearHypothesis( fit3sls[[ 5 ]]$e1wc, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fit3sls[[ 5 ]]$e1wc, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsi[[ 3 ]]$e1, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsi[[ 3 ]]$e1, restrict2, test = "Chisq" )
+print( linearHypothesis( fit3slsi[[ 3 ]]$e1, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fit3slsi[[ 3 ]]$e1, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fit3slsd[[ 4 ]]$e1e, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fit3slsd[[ 4 ]]$e1e, restrict2, test = "Chisq" )
+print( linearHypothesis( fit3slsd[[ 4 ]]$e1e, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fit3slsd[[ 4 ]]$e1e, restrict2, test = "Chisq" )
 
 
 ## *********** model frame *************
