@@ -24,6 +24,7 @@ residuals( theilOls )
 confint( theilOls )
 fitted(theilOls  )
 logLik( theilOls )
+nobs( theilOls )
 model.frame( theilOls )
 model.matrix( theilOls )
 formula( theilOls )
@@ -45,6 +46,7 @@ residuals( theilSur )
 confint( theilSur )
 fitted( theilSur )
 logLik( theilSur )
+nobs( theilSur )
 model.frame( theilSur )
 model.matrix( theilSur )
 formula( theilSur )
@@ -72,6 +74,7 @@ residuals( greeneOls )
 confint(greeneOls  )
 fitted( greeneOls )
 logLik( greeneOls )
+nobs( greeneOls )
 model.frame( greeneOls )
 model.matrix( greeneOls )
 formula( greeneOls )
@@ -97,6 +100,7 @@ residuals( greeneOlsPooled )
 confint( greeneOlsPooled )
 fitted( greeneOlsPooled )
 logLik( greeneOlsPooled )
+nobs( greeneOlsPooled )
 model.frame( greeneOlsPooled )
 model.matrix( greeneOlsPooled )
 formula( greeneOlsPooled )
@@ -118,6 +122,7 @@ residuals( greeneSur )
 confint( greeneSur )
 fitted( greeneSur )
 logLik( greeneSur )
+nobs( greeneSur )
 model.frame( greeneSur )
 model.matrix( greeneSur )
 formula( greeneSur )
@@ -143,6 +148,7 @@ residuals( greeneSurPooled )
 confint( greeneSurPooled )
 fitted( greeneSurPooled )
 logLik( greeneSurPooled )
+nobs( greeneSurPooled )
 model.frame( greeneSurPooled )
 model.matrix( greeneSurPooled )
 formula( greeneSurPooled )
