@@ -43,11 +43,13 @@ system2 <- list( demand = demand, supply = supply2 )
 ## *************** SUR estimation ************************
 fitsur1 <- systemfit( system, "SUR", data = Kmenta, useMatrix = useMatrix )
 print( summary( fitsur1 ) )
+nobs( fitsur1 )
 
 ## ********************* SUR (EViews-like) *****************
 fitsur1e <- systemfit( system, "SUR", data = Kmenta, methodResidCov = "noDfCor",
    useMatrix = useMatrix )
 print( summary( fitsur1e, useDfSys = TRUE ) )
+nobs( fitsur1e )
 
 ## ********************* SUR (methodResidCov="Theil") *****************
 fitsur1r2 <- systemfit( system, "SUR", data = Kmenta, methodResidCov = "Theil",
@@ -68,6 +70,7 @@ print( summary( fitsur1r3 ) )
 fitsur1w <- systemfit( system, "SUR", data = Kmenta, residCovWeighted = TRUE,
    useMatrix = useMatrix )
 summary( fitsur1w )
+nobs( fitsur1w )
 
 ## *************** WSUR (methodResidCov="Theil", useDfSys = TRUE ) ***************
 fitsur1we2 <- systemfit( system, "SUR", data = Kmenta, methodResidCov = "Theil",
@@ -79,10 +82,12 @@ summary( fitsur1we2, useDfSys = TRUE )
 fitsur2 <- systemfit( system, "SUR", data = Kmenta, restrict.matrix = restrm,
    useMatrix = useMatrix )
 print( summary( fitsur2 ) )
+nobs( fitsur2 )
 # the same with symbolically specified restrictions
 fitsur2Sym <- systemfit( system, "SUR", data = Kmenta,
    restrict.matrix = restrict, useMatrix = useMatrix )
 all.equal( fitsur2, fitsur2Sym )
+nobs( fitsur2Sym )
 
 ## *************** SUR with cross-equation restriction (EViews-like) **
 fitsur2e <- systemfit( system, "SUR", data = Kmenta, restrict.matrix = restrm,
@@ -101,6 +106,7 @@ summary( fitsur2we )
 fitsur3 <- systemfit( system, "SUR", data = Kmenta, restrict.regMat = tc,
    useMatrix = useMatrix )
 print( summary( fitsur3 ) )
+nobs( fitsur3 )
 
 ## *************** SUR with restriction via restrict.regMat (EViews-like) **************
 fitsur3e <- systemfit( system, "SUR", data = Kmenta, restrict.regMat = tc,
@@ -118,6 +124,7 @@ summary( fitsur3w )
 fitsur4 <- systemfit( system, "SUR", data = Kmenta, restrict.matrix = restr2m,
    restrict.rhs = restr2q, useMatrix = useMatrix )
 print( summary( fitsur4 ) )
+nobs( fitsur4 )
 # the same with symbolically specified restrictions
 fitsur4Sym <- systemfit( system, "SUR", data = Kmenta,
    restrict.matrix = restrict2, useMatrix = useMatrix )
@@ -151,6 +158,7 @@ fitsur5 <- systemfit( system, "SUR", data = Kmenta, restrict.matrix = restr3m,
    restrict.rhs = restr3q, restrict.regMat = tc,
    x = TRUE, useMatrix = useMatrix )
 print( summary( fitsur5 ) )
+nobs( fitsur5 )
 # the same with symbolically specified restrictions
 fitsur5Sym <- systemfit( system, "SUR", data = Kmenta,
    restrict.matrix = restrict3, restrict.regMat = tc,
@@ -174,6 +182,7 @@ summary( fitsur5w )
 fitsuri1 <- systemfit( system2, "SUR", data = Kmenta, maxit = 100,
    useMatrix = useMatrix )
 print( summary( fitsuri1 ) )
+nobs( fitsuri1 )
 
 ## ************** iterated SUR (EViews-like) *****************
 fitsuri1e <- systemfit( system2, "SUR", data = Kmenta, methodResidCov = "noDfCor",
@@ -284,6 +293,7 @@ fitsuri5e <- systemfit( system2, "SUR", data = Kmenta, methodResidCov = "noDfCor
    restrict.matrix = restr3m, restrict.rhs = restr3q, restrict.regMat = tc,
    maxit = 100, useMatrix = useMatrix )
 print( summary( fitsuri5e ) )
+nobs( fitsuri5e )
 
 ## ********* iterated SUR with 2 restrictions via R and restrict.regMat (methodResidCov="Theil") **********
 fitsurio5r2 <- systemfit( system, "SUR", data = Kmenta, methodResidCov = "Theil",
@@ -319,23 +329,28 @@ fitsurS1 <- systemfit(
    list( price ~ consump - 1, farmPrice ~ consump + trend ), "SUR",
    data = Kmenta, useMatrix = useMatrix )
 print( summary( fitsurS1 ) )
+nobs( fitsurS1 )
 fitsurS2 <- systemfit(
    list( consump ~ price - 1, consump ~ trend - 1 ), "SUR",
    data = Kmenta, useMatrix = useMatrix )
 print( summary( fitsurS2 ) )
+nobs( fitsurS2 )
 fitsurS3 <- systemfit(
    list( consump ~ trend - 1, price ~ trend - 1 ), "SUR",
    data = Kmenta, useMatrix = useMatrix )
+nobs( fitsurS3 )
 print( summary( fitsurS3 ) )
 fitsurS4 <- systemfit(
    list( consump ~ trend - 1, price ~ trend - 1 ), "SUR",
    data = Kmenta, restrict.matrix = matrix( c( 1, -1 ), nrow = 1 ),
    useMatrix = useMatrix )
 print( summary( fitsurS4 ) )
+nobs( fitsurS4 )
 fitsurS5 <- systemfit(
    list( consump ~ 1, price ~ 1 ), "SUR",
    data = Kmenta, useMatrix = useMatrix )
 print( summary( fitsurS5 ) )
+nobs( fitsurS5 )
 
 
 ## **************** shorter summaries **********************
@@ -856,23 +871,23 @@ print( lrtest( fitsuri5e, fitsuri3e, fitsuri1e ) )
 
 ## ************** F tests ****************
 # testing first restriction
-print( linear.hypothesis( fitsur1, restrm ) )
-linear.hypothesis( fitsur1, restrict )
+print( linearHypothesis( fitsur1, restrm ) )
+linearHypothesis( fitsur1, restrict )
 
-print( linear.hypothesis( fitsur1r2, restrm ) )
-linear.hypothesis( fitsur1r2, restrict )
+print( linearHypothesis( fitsur1r2, restrm ) )
+linearHypothesis( fitsur1r2, restrict )
 
-print( linear.hypothesis( fitsuri1e2, restrm ) )
-linear.hypothesis( fitsuri1e2, restrict )
+print( linearHypothesis( fitsuri1e2, restrm ) )
+linearHypothesis( fitsuri1e2, restrict )
 
-print( linear.hypothesis( fitsuri1r3, restrm ) )
-linear.hypothesis( fitsuri1r3, restrict )
+print( linearHypothesis( fitsuri1r3, restrm ) )
+linearHypothesis( fitsuri1r3, restrict )
 
-print( linear.hypothesis( fitsur1we2, restrm ) )
-linear.hypothesis( fitsur1we2, restrict )
+print( linearHypothesis( fitsur1we2, restrm ) )
+linearHypothesis( fitsur1we2, restrict )
 
-print( linear.hypothesis( fitsuri1wr3, restrm ) )
-linear.hypothesis( fitsuri1wr3, restrict )
+print( linearHypothesis( fitsuri1wr3, restrm ) )
+linearHypothesis( fitsuri1wr3, restrict )
 
 # testing second restriction
 restrOnly2m <- matrix(0,1,7)
@@ -882,102 +897,102 @@ restrOnly2m[1,5] <-  1
 restrictOnly2 <- "- demand_price + supply_price = 0.5"
 restrictOnly2i <- "- demand_price + supply_income = 0.5"
 # first restriction not imposed 
-print( linear.hypothesis( fitsur1e2, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsur1e2, restrictOnly2 )
+print( linearHypothesis( fitsur1e2, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsur1e2, restrictOnly2 )
 
-print( linear.hypothesis( fitsuri1, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsuri1, restrictOnly2i )
+print( linearHypothesis( fitsuri1, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsuri1, restrictOnly2i )
 
 # first restriction imposed
-print( linear.hypothesis( fitsur2, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsur2, restrictOnly2 )
+print( linearHypothesis( fitsur2, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsur2, restrictOnly2 )
 
-print( linear.hypothesis( fitsur3, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsur3, restrictOnly2 )
+print( linearHypothesis( fitsur3, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsur3, restrictOnly2 )
 
-print( linear.hypothesis( fitsuri2e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsuri2e, restrictOnly2i )
+print( linearHypothesis( fitsuri2e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsuri2e, restrictOnly2i )
 
-print( linear.hypothesis( fitsuri3e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsuri3e, restrictOnly2i )
+print( linearHypothesis( fitsuri3e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsuri3e, restrictOnly2i )
 
-print( linear.hypothesis( fitsur2we, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsur2we, restrictOnly2 )
+print( linearHypothesis( fitsur2we, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsur2we, restrictOnly2 )
 
-print( linear.hypothesis( fitsuri3we, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitsuri3we, restrictOnly2i )
+print( linearHypothesis( fitsuri3we, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitsuri3we, restrictOnly2i )
 
 # testing both of the restrictions
-print( linear.hypothesis( fitsur1r3, restr2m, restr2q ) )
-linear.hypothesis( fitsur1r3, restrict2 )
+print( linearHypothesis( fitsur1r3, restr2m, restr2q ) )
+linearHypothesis( fitsur1r3, restrict2 )
 
-print( linear.hypothesis( fitsuri1e2, restr2m, restr2q ) )
-linear.hypothesis( fitsuri1e2, restrict2i )
+print( linearHypothesis( fitsuri1e2, restr2m, restr2q ) )
+linearHypothesis( fitsuri1e2, restrict2i )
 
-print( linear.hypothesis( fitsur1w, restr2m, restr2q ) )
-linear.hypothesis( fitsur1w, restrict2 )
+print( linearHypothesis( fitsur1w, restr2m, restr2q ) )
+linearHypothesis( fitsur1w, restrict2 )
 
-print( linear.hypothesis( fitsuri1wr3, restr2m, restr2q ) )
-linear.hypothesis( fitsuri1wr3, restrict2i )
+print( linearHypothesis( fitsuri1wr3, restr2m, restr2q ) )
+linearHypothesis( fitsuri1wr3, restrict2i )
 
 
 ## ************** Wald tests ****************
 # testing first restriction
-print( linear.hypothesis( fitsur1, restrm, test = "Chisq" ) )
-linear.hypothesis( fitsur1, restrict, test = "Chisq" )
+print( linearHypothesis( fitsur1, restrm, test = "Chisq" ) )
+linearHypothesis( fitsur1, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fitsur1r2, restrm, test = "Chisq" ) )
-linear.hypothesis( fitsur1r2, restrict, test = "Chisq" )
+print( linearHypothesis( fitsur1r2, restrm, test = "Chisq" ) )
+linearHypothesis( fitsur1r2, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri1e2, restrm, test = "Chisq" ) )
-linear.hypothesis( fitsuri1e2, restrict, test = "Chisq" )
+print( linearHypothesis( fitsuri1e2, restrm, test = "Chisq" ) )
+linearHypothesis( fitsuri1e2, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri1r3, restrm, test = "Chisq" ) )
-linear.hypothesis( fitsuri1r3, restrict, test = "Chisq" )
+print( linearHypothesis( fitsuri1r3, restrm, test = "Chisq" ) )
+linearHypothesis( fitsuri1r3, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fitsur1w, restrm, test = "Chisq" ) )
-linear.hypothesis( fitsur1w, restrict, test = "Chisq" )
+print( linearHypothesis( fitsur1w, restrm, test = "Chisq" ) )
+linearHypothesis( fitsur1w, restrict, test = "Chisq" )
 
 # testing second restriction
 # first restriction not imposed
-print( linear.hypothesis( fitsur1e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsur1e2, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitsur1e2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsur1e2, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri1, restrictOnly2i, test = "Chisq" )
+print( linearHypothesis( fitsuri1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsuri1, restrictOnly2i, test = "Chisq" )
 
 # first restriction imposed
-print( linear.hypothesis( fitsur2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsur2, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitsur2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsur2, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitsur3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsur3, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitsur3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsur3, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri2e, restrictOnly2i, test = "Chisq" )
+print( linearHypothesis( fitsuri2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsuri2e, restrictOnly2i, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri3e, restrictOnly2i, test = "Chisq" )
+print( linearHypothesis( fitsuri3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsuri3e, restrictOnly2i, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri2w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri2w, restrictOnly2i, test = "Chisq" )
+print( linearHypothesis( fitsuri2w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsuri2w, restrictOnly2i, test = "Chisq" )
 
-print( linear.hypothesis( fitsur3w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitsur3w, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitsur3w, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitsur3w, restrictOnly2, test = "Chisq" )
 
 
 # testing both of the restrictions
-print( linear.hypothesis( fitsur1r3, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitsur1r3, restrict2, test = "Chisq" )
+print( linearHypothesis( fitsur1r3, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitsur1r3, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri1e2, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri1e2, restrict2i, test = "Chisq" )
+print( linearHypothesis( fitsuri1e2, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitsuri1e2, restrict2i, test = "Chisq" )
 
-print( linear.hypothesis( fitsur1we2, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitsur1we2, restrict2, test = "Chisq" )
+print( linearHypothesis( fitsur1we2, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitsur1we2, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fitsuri1wr3, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitsuri1wr3, restrict2i, test = "Chisq" )
+print( linearHypothesis( fitsuri1wr3, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitsuri1wr3, restrict2i, test = "Chisq" )
 
 
 ## ****************** model frame **************************
