@@ -61,6 +61,7 @@ fitw2sls2e <- systemfit( system, "W2SLS", data = Kmenta, restrict.matrix = restr
    inst = inst, methodResidCov = "noDfCor", x = TRUE,
    useMatrix = useMatrix )
 print( summary( fitw2sls2e, useDfSys = TRUE ) )
+nobs( fitw2sls2e )
 
 ## ********************* W2SLS with restriction via restrict.regMat *******************
 fitw2sls3 <- systemfit( system, "W2SLS", data = Kmenta, restrict.regMat = tc,
@@ -447,11 +448,11 @@ print( logLik( fitw2slsd3e ) )
 
 ## ************** F tests ****************
 # testing first restriction
-print( linear.hypothesis( fitw2sls1, restrm ) )
-linear.hypothesis( fitw2sls1, restrict )
+print( linearHypothesis( fitw2sls1, restrm ) )
+linearHypothesis( fitw2sls1, restrict )
 
-print( linear.hypothesis( fitw2slsd1e, restrm ) )
-linear.hypothesis( fitw2slsd1e, restrict )
+print( linearHypothesis( fitw2slsd1e, restrm ) )
+linearHypothesis( fitw2slsd1e, restrict )
 
 # testing second restriction
 restrOnly2m <- matrix(0,1,7)
@@ -460,67 +461,67 @@ restrOnly2m[1,2] <- -1
 restrOnly2m[1,5] <-  1
 restrictOnly2 <- "- demand_price + supply_price = 0.5"
 # first restriction not imposed 
-print( linear.hypothesis( fitw2sls1e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2sls1e, restrictOnly2 )
+print( linearHypothesis( fitw2sls1e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2sls1e, restrictOnly2 )
 
-print( linear.hypothesis( fitw2slsd1, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2slsd1, restrictOnly2 )
+print( linearHypothesis( fitw2slsd1, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2slsd1, restrictOnly2 )
 
 # first restriction imposed
-print( linear.hypothesis( fitw2sls2, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2sls2, restrictOnly2 )
+print( linearHypothesis( fitw2sls2, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2sls2, restrictOnly2 )
 
-print( linear.hypothesis( fitw2sls3, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2sls3, restrictOnly2 )
+print( linearHypothesis( fitw2sls3, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2sls3, restrictOnly2 )
 
-print( linear.hypothesis( fitw2slsd2e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2slsd2e, restrictOnly2 )
+print( linearHypothesis( fitw2slsd2e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2slsd2e, restrictOnly2 )
 
-print( linear.hypothesis( fitw2slsd3e, restrOnly2m, restrOnly2q ) )
-linear.hypothesis( fitw2slsd3e, restrictOnly2 )
+print( linearHypothesis( fitw2slsd3e, restrOnly2m, restrOnly2q ) )
+linearHypothesis( fitw2slsd3e, restrictOnly2 )
 
 # testing both of the restrictions
-print( linear.hypothesis( fitw2sls1e, restr2m, restr2q ) )
-linear.hypothesis( fitw2sls1e, restrict2 )
+print( linearHypothesis( fitw2sls1e, restr2m, restr2q ) )
+linearHypothesis( fitw2sls1e, restrict2 )
 
-print( linear.hypothesis( fitw2slsd1, restr2m, restr2q ) )
-linear.hypothesis( fitw2slsd1, restrict2 )
+print( linearHypothesis( fitw2slsd1, restr2m, restr2q ) )
+linearHypothesis( fitw2slsd1, restrict2 )
 
 
 ## ************** Wald tests ****************
 # testing first restriction
-print( linear.hypothesis( fitw2sls1, restrm, test = "Chisq" ) )
-linear.hypothesis( fitw2sls1, restrict, test = "Chisq" )
+print( linearHypothesis( fitw2sls1, restrm, test = "Chisq" ) )
+linearHypothesis( fitw2sls1, restrict, test = "Chisq" )
 
-print( linear.hypothesis( fitw2slsd1e, restrm, test = "Chisq" ) )
-linear.hypothesis( fitw2slsd1e, restrict, test = "Chisq" )
+print( linearHypothesis( fitw2slsd1e, restrm, test = "Chisq" ) )
+linearHypothesis( fitw2slsd1e, restrict, test = "Chisq" )
 
 # testing second restriction
 # first restriction not imposed
-print( linear.hypothesis( fitw2sls1e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2sls1e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2sls1e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2sls1e, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitw2slsd1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2slsd1, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2slsd1, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2slsd1, restrictOnly2, test = "Chisq" )
 # first restriction imposed
-print( linear.hypothesis( fitw2sls2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2sls2, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2sls2, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2sls2, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitw2sls3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2sls3, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2sls3, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2sls3, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitw2slsd2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2slsd2e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2slsd2e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2slsd2e, restrictOnly2, test = "Chisq" )
 
-print( linear.hypothesis( fitw2slsd3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
-linear.hypothesis( fitw2slsd3e, restrictOnly2, test = "Chisq" )
+print( linearHypothesis( fitw2slsd3e, restrOnly2m, restrOnly2q, test = "Chisq" ) )
+linearHypothesis( fitw2slsd3e, restrictOnly2, test = "Chisq" )
 
 # testing both of the restrictions
-print( linear.hypothesis( fitw2sls1e, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitw2sls1e, restrict2, test = "Chisq" )
+print( linearHypothesis( fitw2sls1e, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitw2sls1e, restrict2, test = "Chisq" )
 
-print( linear.hypothesis( fitw2slsd1, restr2m, restr2q, test = "Chisq" ) )
-linear.hypothesis( fitw2slsd1, restrict2, test = "Chisq" )
+print( linearHypothesis( fitw2slsd1, restr2m, restr2q, test = "Chisq" ) )
+linearHypothesis( fitw2slsd1, restrict2, test = "Chisq" )
 
 
 ## ****************** model frame **************************
